From d3dad0dc820d7baf365cc10288fdb5094a7babfa Mon Sep 17 00:00:00 2001
From: yubo <autumnal_wind@yeah.net>
Date: 星期四, 19 三月 2026 10:32:41 +0800
Subject: [PATCH] fix(hr): 修复员工信息导入时身份证有效期设置问题
---
febs-server/febs-server-hr/src/main/java/cc/mrbird/febs/server/hr/service/IEmpPhysicalExamService.java | 108 +++++++++++++++++++++++++++++++++---------------------
1 files changed, 66 insertions(+), 42 deletions(-)
diff --git a/febs-server/febs-server-hr/src/main/java/cc/mrbird/febs/server/hr/service/IEmpPhysicalExamService.java b/febs-server/febs-server-hr/src/main/java/cc/mrbird/febs/server/hr/service/IEmpPhysicalExamService.java
index 2cab6d7..bdbafd4 100644
--- a/febs-server/febs-server-hr/src/main/java/cc/mrbird/febs/server/hr/service/IEmpPhysicalExamService.java
+++ b/febs-server/febs-server-hr/src/main/java/cc/mrbird/febs/server/hr/service/IEmpPhysicalExamService.java
@@ -1,5 +1,6 @@
package cc.mrbird.febs.server.hr.service;
+import cc.mrbird.febs.common.core.entity.system.DicItem;
import cc.mrbird.febs.server.hr.entity.EmpPhysicalExam;
import cc.mrbird.febs.common.core.entity.QueryRequest;
@@ -9,51 +10,74 @@
import java.util.List;
/**
-*
-* name:EmpPhysicalexam
-* package:cc.mrbird.febs.server.hr.controller
-* description:员工体检信息服务接口
-*
-* @author luoyibo
-* @date 2021-01-24 20:35:19
-* @since JDK1.8
-*/
+ * name:EmpPhysicalexam
+ * package:cc.mrbird.febs.server.hr.controller
+ * description:员工体检信息服务接口
+ *
+ * @author luoyibo
+ * @date 2021-01-31 09:11:00
+ * @since JDK1.8
+ */
public interface IEmpPhysicalExamService extends IService<EmpPhysicalExam> {
-/**
-* 查询(分页)
-*
-* @param request QueryRequest
-* @param empPhysicalexam empPhysicalexam
-* @return IPage<EmpPhysicalexam>
-*/
-IPage<EmpPhysicalExam> findEmpPhysicalexams(QueryRequest request, EmpPhysicalExam empPhysicalexam);
+ /**
+ * 查询(分页)
+ *
+ * @param request QueryRequest
+ * @param empPhysicalExam empPhysicalExam
+ * @return IPage<EmpPhysicalExam>
+ */
+ IPage<EmpPhysicalExam> findEmpPhysicalExams(QueryRequest request, EmpPhysicalExam empPhysicalExam);
-/**
-* 查询(所有)
-*
-* @param empPhysicalexam empPhysicalexam
-* @return List<EmpPhysicalexam>
-*/
-List<EmpPhysicalExam> findEmpPhysicalexams(EmpPhysicalExam empPhysicalexam);
+ /**
+ * 查询(所有)
+ *
+ * @param empPhysicalExam empPhysicalExam
+ * @return List<EmpPhysicalExam>
+ */
+ List<EmpPhysicalExam> findEmpPhysicalExams(EmpPhysicalExam empPhysicalExam);
-/**
-* 新增
-*
-* @param empPhysicalexam empPhysicalexam
-*/
-void createEmpPhysicalexam(EmpPhysicalExam empPhysicalexam);
+ /**
+ * 新增
+ *
+ * @param empPhysicalExam empPhysicalExam
+ */
+ void createEmpPhysicalExam(EmpPhysicalExam empPhysicalExam);
-/**
-* 修改
-*
-* @param empPhysicalexam empPhysicalexam
-*/
-void updateEmpPhysicalexam(EmpPhysicalExam empPhysicalexam);
+ /**
+ * 修改
+ *
+ * @param empPhysicalExam empPhysicalExam
+ */
+ void updateEmpPhysicalExam(EmpPhysicalExam empPhysicalExam);
-/**
-* 删除
-*
-* @param empPhysicalexam empPhysicalexam
-*/
-void deleteEmpPhysicalexam(EmpPhysicalExam empPhysicalexam);
+ /**
+ * 删除
+ *
+ * @param empPhysicalExam empPhysicalExam
+ */
+ void deleteEmpPhysicalExam(EmpPhysicalExam empPhysicalExam);
+
+ /**
+ * 根据Id批量逻辑删除记录
+ * <p>
+ * date 2021-01-28 10:48
+ *
+ * @param ids 待删除Id
+ * @return void
+ * @author: luoyibo
+ */
+ void logicDelEmpPhysicalExam(String ids);
+
+ /**
+ * 从暂存状态转成正式状态
+ * <p>
+ * date 2021-02-04 21:11
+ *
+ * @param ids 待转换记录Id
+ * @return boolean
+ * @author: luoyibo
+ */
+ boolean momentToNormal(String ids);
+
+ void importEmpPhysicalExam(List<List<Object>> listObject,List<String> returnList,List<DicItem> dicItems);
}
--
Gitblit v1.8.0